ULinkApiClient class

Client for interacting with ULink API

Constructors

ULinkApiClient({required String baseUrl, String? apiKey, String? jwtToken})

Properties

apiKey String?
Get API key from explicit param or config
no setter
baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProjectBySlug(String slug) Future<ProjectListItem>
Get a project by its slug
getProjectConfig(String projectId) Future<ProjectConfig>
Get project configuration
getProjectDomains(String projectId) Future<List<DomainConfig>>
Get project domains
getProjects() Future<List<ProjectListItem>>
Get all projects for the authenticated user
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postVerificationResults(String projectId, Map<String, dynamic> verificationReport) Future<void>
Post verification results to the API for onboarding
testConnection() Future<bool>
Test API connection
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited