AuthService class

Service for Supabase authentication

Constructors

AuthService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getValidToken({String? supabaseUrl, String? supabaseAnonKey}) Future<String?>
Get valid token, refreshing proactively if expiring soon.
isTokenValid(AuthConfig? auth) bool
Validate token by checking expiration
loginWithEmailPassword({required String email, required String password, required String supabaseUrl, required String supabaseAnonKey}) Future<AuthConfig>
Authenticate with email and password
refreshToken({required String refreshToken, required String supabaseUrl, required String supabaseAnonKey}) Future<AuthConfig>
Refresh access token using refresh token