BrowserAuthService class

Service for browser-based authentication

Constructors

BrowserAuthService({required String frontendUrl, bool verbose = false})

Properties

frontendUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

authenticate() Future<AuthConfig>
Authenticate using browser-based flow Returns AuthConfig on success, throws on error
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited