ConfigManager class

Manages CLI configuration file

Constructors

ConfigManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

configDir String
no setter
configPath String
no setter

Static Methods

clearConfig() Future<void>
Clear configuration (logout)
isLoggedIn() bool
Check if user is logged in Returns true if token is valid OR if a refresh token is available
loadConfig() CliConfig?
Load configuration from file
saveConfig(CliConfig config) Future<void>
Save configuration to file
updateAuth(AuthConfig auth) Future<void>
Update auth in config
updateSupabaseConfig({String? url, String? anonKey}) Future<void>
Update Supabase configuration