AuthCallbackResult class

Result from the local auth server callback

Constructors

AuthCallbackResult({String? code, String? accessToken, String? refreshToken, int? expiresIn, String? error, String? session})

Properties

accessToken String?
final
code String?
final
error String?
final
expiresIn int?
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
refreshToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited