DomainVerifyOptions class

Options for a standalone domain verify run.

Constructors

DomainVerifyOptions({String? domain, String? ios, String? android, bool json = false, bool help = false})

Properties

android String?
final
domain String?
final
hashCode int
The hash code for this object.
no setterinherited
help bool
final
ios String?
final
json bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited