ImportOptions class

Options for an import firebase run.

Constructors

ImportOptions({String? input, String? domain, String? out, bool live = false, bool verify = true, bool json = false, bool help = false, String? apiKey})

Properties

apiKey String?
final
domain String?
final
hashCode int
The hash code for this object.
no setterinherited
help bool
final
input String?
final
json bool
final
live bool
final
out String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verify bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited