ImportRunResult class

Result of running import firebase — the process exit code plus the generated manifest (so callers/tests can inspect the outcome).

Constructors

ImportRunResult(int exitCode, Map<String, dynamic> manifest)

Properties

exitCode int
final
hashCode int
The hash code for this object.
no setterinherited
manifest Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited