LoginCommand class

Command for logging in to ULink

Constructors

LoginCommand({bool verbose = false, String baseUrl = 'https://api.ulink.ly'})

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

execute({bool useApiKey = false, bool usePassword = false}) Future<void>
Execute login
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited