ProjectCommand class

Command for managing project selection

Constructors

ProjectCommand({required String baseUrl, bool verbose = false})

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProject(String? projectPath, {String? slug}) Future<void>
Set project for current directory
showCurrent(String? projectPath) Future<void>
Show current project for directory
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited