ResolveOptions class

Options for a resolve run.

Constructors

ResolveOptions({String? url, String? apiKey, bool json = false, bool help = false})

Properties

apiKey String?
final
hashCode int
The hash code for this object.
no setterinherited
help bool
final
json bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited