ULinkConstants class

ULink CLI embedded configuration constants These values are embedded in the CLI binary for security and performance

Constructors

ULinkConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

supabaseAnonKey → const String
Supabase anonymous key for authentication This is a public key designed to be embedded in client applications
supabaseUrl → const String
Supabase project URL for authentication