ULinkVersion class

ULink CLI version information

Constructors

ULinkVersion()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fullVersion String
Get full version string
no setter
shortVersion String
Get short version string for display
no setter
versionInfo String
Get version info as a formatted string
no setter

Constants

buildDate → const String
Build date (ISO 8601 format)
buildNumber → const String
Build number (incremented with each build)
version → const String
Current version of the CLI tool