LiveParityResult class

Constructors

LiveParityResult(List<LiveCheck> checks)

Properties

checks List<LiveCheck>
final
failures List<LiveCheck>
no setter
hashCode int
The hash code for this object.
no setterinherited
ok bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited