ParityResult class

Constructors

ParityResult(List<ParityCheck> checks)

Properties

checks List<ParityCheck>
final
failures List<ParityCheck>
no setter
hashCode int
The hash code for this object.
no setterinherited
ok bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited