AuthConfig class

Authentication configuration models

Constructors

AuthConfig({required AuthType type, String? token, String? apiKey, String? refreshToken, DateTime? expiresAt, UserInfo? user})
AuthConfig.fromJson(Map<String, dynamic> json)
factory

Properties

apiKey String?
final
expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
isExpired bool
no setter
isExpiringSoon bool
True if token expires within 5 minutes
no setter
refreshToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
final
type AuthType
final
user UserInfo?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited