CliConfig class

Complete CLI configuration

Constructors

CliConfig({AuthConfig? auth, List<ProjectInfo> projects = const [], String? supabaseUrl, String? supabaseAnonKey})
CliConfig.fromJson(Map<String, dynamic> json)
factory

Properties

auth AuthConfig?
final
hashCode int
The hash code for this object.
no setterinherited
projects List<ProjectInfo>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supabaseAnonKey String?
final
supabaseUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited