ProjectInfo class
Project information
Constructors
- ProjectInfo({required String projectId, required String projectName, String? apiKey})
-
ProjectInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- apiKey → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectId → String
-
final
- projectName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited