DomainConfig class
Domain configuration
Constructors
- DomainConfig({required String id, required String host, required String status, bool isPrimary = false})
-
DomainConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited