ProjectConfig class

ULink project configuration from API

Constructors

ProjectConfig({required String projectId, String? iosBundleIdentifier, String? iosTeamId, String? iosDeeplinkSchema, String? androidPackageName, List<String> androidSha256Fingerprints = const [], String? androidDeeplinkSchema, List<DomainConfig> domains = const []})
ProjectConfig.fromJson(Map<String, dynamic> json)
factory

Properties

androidDeeplinkSchema String?
final
androidPackageName String?
final
androidSha256Fingerprints List<String>
final
domains List<DomainConfig>
final
hashCode int
The hash code for this object.
no setterinherited
iosBundleIdentifier String?
final
iosDeeplinkSchema String?
final
iosTeamId String?
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited