TargetInfo class

Information about an iOS target discovered in the project

Constructors

TargetInfo({required File entitlementsFile, required File infoPlistFile, required String bundleId, required String targetName})

Properties

bundleId String
final
entitlementsFile File
final
hashCode int
The hash code for this object.
no setterinherited
infoPlistFile File
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited