VerificationResult class

Result of a verification check

Constructors

VerificationResult({required String checkName, required VerificationStatus status, String? message, String? fixSuggestion, Map<String, dynamic>? details})

Properties

checkName String
final
details Map<String, dynamic>?
final
fixSuggestion String?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status VerificationStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited