AndroidParser class

Parser for Android AndroidManifest.xml files

Constructors

AndroidParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseAndroidManifest(File manifestFile) PlatformConfig?
Parse AndroidManifest.xml file