GradleParser class

Parser for Gradle build files (build.gradle and build.gradle.kts)

Constructors

GradleParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractPackageName(File gradleFile) String?
Extract package name from build.gradle or build.gradle.kts
extractSdkVersion(File gradleFile) String?
Extract SDK version if present
hasUlinkSdk(File gradleFile) bool
Check if ULink SDK dependency exists