IosParser class

Parser for iOS Info.plist files

Constructors

IosParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractTeamId(String? bundleIdentifier) String?
Extract team ID from bundle identifier (if it contains team ID) Note: This is a best-effort approach. Team ID is usually in the entitlements or Xcode project settings, not directly in Info.plist
parseEntitlements(File entitlementsFile) List<String>
Parse entitlements file
parseInfoPlist(File infoPlistFile) PlatformConfig?
Parse Info.plist file