ProjectDetector class

Detects project type and finds configuration files

Constructors

ProjectDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detectProjectType(String projectPath) ProjectType
Detect project type from directory structure
discoverTargetByBundleId(String projectPath, ProjectType projectType, String? targetBundleId) TargetDiscoveryResult
Discover iOS target by bundle ID Returns all discovered targets plus the one matching the requested bundle ID
findAllEntitlements(String projectPath, ProjectType projectType) List<File>
Find all entitlements files for iOS/Flutter projects
findAndroidManifest(String projectPath, ProjectType projectType) File?
Find AndroidManifest.xml for Android/Flutter projects
findEntitlements(String projectPath, ProjectType projectType) File?
Find entitlements file for iOS/Flutter projects
findGradleFiles(String projectPath, ProjectType projectType) List<File>
Find build.gradle or build.gradle.kts for Android/Flutter projects
findInfoPlist(String projectPath, ProjectType projectType) File?
Find Info.plist file for iOS/Flutter projects
findInfoPlistForEntitlements(File entitlementsFile) File?
Find the Info.plist associated with an entitlements file Searches: same directory, parent directory, sibling directories, recursive in target folder
findPackageSwift(String projectPath, ProjectType projectType) File?
Find Package.swift for iOS projects
findPodfile(String projectPath, ProjectType projectType) File?
Find Podfile for iOS/Flutter projects
findPubspecYaml(String projectPath) File?
Find pubspec.yaml for Flutter projects