ReportGenerator class

Generator for verification reports

Constructors

ReportGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateJsonReport(VerificationReport report) Map<String, dynamic>
Generate a JSON report
generateReport(VerificationReport report, {bool verbose = false}) String
Generate a formatted report