AndroidRuntimeTester class

Runtime tester for Android App Links

Constructors

AndroidRuntimeTester()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAppLinksStatus(String packageName) Future<VerificationResult>
Get app links verification status
isAdbAvailable() Future<bool>
Check if ADB is available
isDeviceConnected() Future<bool>
Check if device is connected
Force re-verification of app links
Test opening an app link