AssetlinksApp class

A single android_app statement from an assetlinks.json file: the declared package and its SHA-256 certificate fingerprints.

Constructors

AssetlinksApp(String package, List<String> fingerprints)

Properties

fingerprints List<String>
final
hashCode int
The hash code for this object.
no setterinherited
package String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited