ConsoleStyle class

Utility class for styled console output with TTY detection

Constructors

ConsoleStyle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bold(String text) String
Bold text
dim(String text) String
Dimmed/gray text
error(String text) String
Red text for errors
errorBold(String text) String
Bold red for error headers
info(String text) String
Cyan text for info
infoBold(String text) String
Bold cyan for info headers
success(String text) String
Green text for success
successBold(String text) String
Bold green for success headers
warning(String text) String
Yellow text for warnings
warningBold(String text) String
Bold yellow for warning headers