ProgressSpinner class

Wrapper for progress spinners with TTY detection

Constructors

ProgressSpinner(String message, {bool verbose = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

fail(String msg) → void
Stop with failure status
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Start the spinner
stop() → void
Stop spinner without changing message (for custom handling)
success(String msg) → void
Stop with success status
toString() String
A string representation of this object.
inherited
update(String newMessage) → void
Update the spinner text
warn(String msg) → void
Stop with warning status

Operators

operator ==(Object other) bool
The equality operator.
inherited