ConfigValidator class

Validator for cross-referencing local configs with ULink config

Constructors

ConfigValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validateAndroid(PlatformConfig localConfig, ProjectConfig ulinkConfig) List<VerificationResult>
Validate Android configuration
validateIos(PlatformConfig localConfig, ProjectConfig ulinkConfig) List<VerificationResult>
Validate iOS configuration