SdkPackageValidator class

Validates that ULink SDK package is installed

Constructors

SdkPackageValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(String projectPath, ProjectType projectType) List<VerificationResult>
Validate SDK installation for a project