CreateOutcome class
Outcome of a create (live or preview).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
link
→ Map<
String, dynamic> -
For preview: the internal ULink link map. For live: the API response body.
final
-
payload
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortLink → String
-
final
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited