ResolveRunResult class
Result of running resolve — the process exit code plus the resolved
profile (or null on failure), so callers/tests can inspect the outcome.
Constructors
- ResolveRunResult(int exitCode, ResolveProfile? profile)
Properties
- exitCode → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- profile → ResolveProfile?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited