ProjectConfigManager class
Manages per-directory project configuration Stores project ID in .ulink/project.json in the current directory
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
loadProjectId(
String projectPath) → String? - Load project ID from directory config
-
saveProjectId(
String projectPath, String projectId, {String? projectName}) → Future< void> - Save project ID to directory config
Constants
- configDirName → const String
- configFileName → const String