PlatformConfig class
Local platform configuration extracted from project files
Constructors
-
PlatformConfig({required ProjectType projectType, String? bundleIdentifier, String? packageName, List<
String> urlSchemes = const [], List<String> iosUrlSchemes = const [], List<String> androidUrlSchemes = const [], List<String> associatedDomains = const [], List<String> appLinkHosts = const [], List<String> sha256Fingerprints = const [], String? teamId})
Properties
-
androidUrlSchemes
→ List<
String> -
final
-
appLinkHosts
→ List<
String> -
final
-
associatedDomains
→ List<
String> -
final
- bundleIdentifier → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
iosUrlSchemes
→ List<
String> -
final
- packageName → String?
-
final
- projectType → ProjectType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sha256Fingerprints
→ List<
String> -
final
- teamId → String?
-
final
-
urlSchemes
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited