TargetDiscoveryResult class
Result of target discovery operation
Constructors
-
TargetDiscoveryResult({required TargetInfo? matchedTarget, required List<
TargetInfo> allTargets, required String? requestedBundleId})
Properties
-
allTargets
→ List<
TargetInfo> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMatch → bool
-
Whether a matching target was found
no setter
- hasMultipleTargets → bool
-
Whether multiple targets were discovered in the project
no setter
- matchedTarget → TargetInfo?
-
final
- requestedBundleId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited