VerificationReport class
Complete verification report
Constructors
-
VerificationReport({required ProjectType projectType, required List<
VerificationResult> results, DateTime? timestamp})
Properties
- errorCount → int
-
no setter
- hasErrors → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWarnings → bool
-
no setter
- projectType → ProjectType
-
final
-
results
→ List<
VerificationResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successCount → int
-
no setter
- timestamp → DateTime
-
final
- warningCount → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited