ReactNativeParser class
Parser for React Native / Expo projects (combines iOS and Android parsing).
React Native is cross-platform like Flutter, but its native directories only
exist for bare RN projects or after expo prebuild. When they are absent
(managed Expo workflow), the returned config simply has empty native fields
and the verifier reports that native config is plugin-managed.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseReactNativeProject(
String projectPath) → PlatformConfig?