IosRuntimeTester class
Runtime tester for iOS Universal Links
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkDomainAssociationStatus(
String domain, String? bundleIdentifier) → Future< VerificationResult> - Check domain association status using swcutil_ctl (iOS 16+) This is the proper way to check if a domain is associated with an app
-
getBootedSimulator(
) → Future< String?> - Get booted simulator ID
-
isAppInstalled(
String bundleIdentifier, String? simulatorId) → Future< bool> - Check if app is installed on simulator
-
isSimulatorAvailable(
) → Future< bool> - Check if iOS simulator is available