UpdateChecker class
Checks for CLI updates (once per day)
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkForUpdates(
) → Future< void> - Check for updates and print message if available This is non-blocking and fails silently
-
showCachedUpdateMessage(
) → void - Check if we have a cached update message to show This is synchronous and fast - used when we skip the network check